==> micromap_1.9.1.tar.gz: micromap/inst/NEWS.Rd <==
\name{NEWS}
\title{micromap News}

\section{CHANGES IN micromap VERSION 1.9.1 (Released 2015-01-23)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Revised the CITATION file to reference the article in the Journal
        of Statistical Software.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.9 (Released 2014-05-27)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Added an index.html file to the doc directory so that files in the
        directory can be viewed from the package help page.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.8 (Released 2014-03-20)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Created a print method for objects of class mm (micromap).
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.7 (Released 2014-01-08)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Added shading options for micromaps.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.6 (Released 2013-05-31)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item Renamed the statesShapefile dataset to USstates.

      \item Created a list of variables that are defined globally when the check
        tool is applied to the package.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}

\section{CHANGES IN micromap VERSION 1.5 (Released 2012-12-18)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item This is the original CRAN release of the package.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}

==> micromap_1.9.3.tar.gz: micromap/inst/NEWS.Rd <==
\name{NEWS}
\title{micromap News}

\section{CHANGES IN micromap VERSION 1.9.3 (Released 2018-02-05)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item trans argument added to mmplot for axis transformations.    
      \item mmplot includes a method for SpatialPolygonsDataFrame objects.
      \item Plot objects no longer open in a separate graphics window.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item Expanded color ramp to include all observations in a perceptual grouping.
      \item Fixed namespace conflicts between grid and ggplot 2.x.
      \item Font for text called explicitly as 'sans' to prevent warning of 'font family not found'.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.9.2 (Released 2015-02-06)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item None.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item  Revised the DESCRIPTION file to avoid errors for functions imported
        from other packages.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.9.1 (Released 2015-01-23)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Revised the CITATION file to reference the article in the Journal
        of Statistical Software.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.9 (Released 2014-05-27)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Added an index.html file to the doc directory so that files in the
        directory can be viewed from the package help page.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.8 (Released 2014-03-20)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Created a print method for objects of class mm (micromap).
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.7 (Released 2014-01-08)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item  Added shading options for micromaps.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}


\section{CHANGES IN micromap VERSION 1.6 (Released 2013-05-31)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item Renamed the statesShapefile dataset to USstates.

      \item Created a list of variables that are defined globally when the check
        tool is applied to the package.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}

\section{CHANGES IN micromap VERSION 1.5 (Released 2012-12-18)}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item This is the original CRAN release of the package.
    }
  }

  \subsection{BUG FIXES}{
    \itemize{
      \item None.
    }
  }
}
